@@ -23,17 +23,7 @@ hansard_tidy <- function(df, tidy_style) {
     if ("about" %in% names(df)) {
       df$about <- gsub("http://data.parliament.uk/resources/", "", df$about)
     }
-
-    if (tidy_style == "camelCase") {
-      names(df) <- gsub("(^|[^[:alnum:]])([[:alnum:]])", "\\U\\2",
-        names(df),
-        perl = TRUE
-      )
-
-      substr(names(df), 1, 1) <- tolower(substr(names(df), 1, 1))
-    } else if (tidy_style == "period.case") {
-      names(df) <- gsub("_", "\\.", names(df), perl = TRUE)
-    }
+    names(df) <- snakecase::to_any_case(names(df), case = tidy_style)
   }
 
   df
